#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 postgrest
version:              10.1.0
visibility:           public
id:                   postgrest-10.1.0-F3E0yZbvsfk4XDJXTb5O4s
key:                  postgrest-10.1.0-F3E0yZbvsfk4XDJXTb5O4s
license:              MIT
maintainer:           Steve Chavez <stevechavezast@gmail.com>
author:               Joe Nelson, Adam Baker, Steve Chavez
homepage:             https://postgrest.org
synopsis:             REST API for any Postgres database
description:
    Reads the schema of a PostgreSQL database and creates RESTful routes
    for tables, views, and functions, supporting all HTTP methods that security
    permits.

category:             Executable, PostgreSQL, Network APIs
abi:                  25e59f6fe776852bbb4f12ae18c49291
exposed:              True
exposed-modules:
    PostgREST.ApiRequest PostgREST.ApiRequest.Preferences
    PostgREST.ApiRequest.QueryParams PostgREST.ApiRequest.Types
    PostgREST.App PostgREST.AppState PostgREST.Auth PostgREST.CLI
    PostgREST.Config PostgREST.Config.Database PostgREST.Config.JSPath
    PostgREST.Config.PgVersion PostgREST.Config.Proxy PostgREST.Cors
    PostgREST.Error PostgREST.Logger PostgREST.MediaType PostgREST.Plan
    PostgREST.Plan.CallPlan PostgREST.Plan.MutatePlan
    PostgREST.Plan.ReadPlan PostgREST.Query
    PostgREST.Query.QueryBuilder PostgREST.Query.SqlFragment
    PostgREST.Query.Statements PostgREST.RangeQuery PostgREST.Response
    PostgREST.Response.GucHeader PostgREST.Response.OpenAPI
    PostgREST.SchemaCache PostgREST.SchemaCache.Identifiers
    PostgREST.SchemaCache.Proc PostgREST.SchemaCache.Relationship
    PostgREST.SchemaCache.Table PostgREST.Unix PostgREST.Version
    PostgREST.Workers

hidden-modules:       Paths_postgrest
import-dirs:          /usr/lib/ghc-9.6.6/site-local/postgrest-10.1.0
library-dirs:         /usr/lib/ghc-9.6.6/site-local/postgrest-10.1.0
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/postgrest-10.1.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/postgrest
hs-libraries:         HSpostgrest-10.1.0-F3E0yZbvsfk4XDJXTb5O4s
depends:
    HTTP-4000.5.0-29My2OaQSieA4vfM4aK9Md
    Ranged-sets-0.5.0-3BPQonjgKW0JfQq9fEagr7
    aeson-2.2.2.0-GDAHVM41MmSECw1rdoDU4M
    auto-update-0.1.6-G55mfWHOSg7HMFAPsKwztL base-4.18.2.1
    base64-bytestring-1.2.1.0-5lxolF3Oyq7A5PTLpqan5r
    bytestring-0.11.5.3 case-insensitive-1.2.1.0-J0VBpVSR64y7EsTz8jFcGs
    cassava-0.5.4.1-IGb8633sDlPIwq4k5QNX3C
    configurator-pg-0.2.11-IgAHZyGQhsY8N6uOO8xAyY containers-0.6.7
    contravariant-extras-0.3.5.4-Jp1EzHgD0E5KQ707vKnuxI
    cookie-0.5.0-Dqi2dsQ09KG8Z0mbWITxu5 directory-1.3.8.5
    either-5.0.3-DAoFe2uMxJAGoC8cmfw1xL
    gitrev-1.3.1-HjgHeGOzFY1JvYhlt8eDSs
    hasql-1.6.1.1-HJp6fa6VS3KDy8IlxHMd1l
    hasql-dynamic-statements-0.3.1.2-GlXEuzahkhbHioXJhtadMd
    hasql-notifications-0.2.0.5-4ISCvkTQWGoBw8pYmamMSm
    hasql-pool-0.8.0.2-Gn6pptIeW6v8UUzC5FCxQl
    hasql-transaction-1.0.1.2-HZgYY2QmQsfAu2s2aOSrWA
    heredoc-0.2.0.0-6fzsisYvDUd6tBbd4jIzIt
    http-types-0.12.4-G7h7u8FYl0yCakR0583rKK
    insert-ordered-containers-0.2.5.3-HPDdRjDM9je5Qc2GEhtdcN
    interpolatedstring-perl6-1.0.2-KPpZ56K0oInLoX1TkV4JyU
    jose-0.10.0.1-3L5BVI7MmojEUtEhEfykWo
    lens-5.3.4-8J9QWgGw3wI75Yrk4Lq8ak
    lens-aeson-1.2.3-6TXuxLzR7lIBojMkcktRwS mtl-2.3.1
    network-3.1.4.0-C8IvtFvf3OVKggpOXnCQiO
    network-uri-2.6.4.2-3gjzmu5JQ7Z8RcINbgIB8U
    optparse-applicative-0.18.1.0-vPoWCngm2S3ZG61FOtDDl parsec-3.1.16.1
    protolude-0.3.5-JKA2rmmxstGft8q59qxYb
    regex-tdfa-1.3.2.5-7bufusrWbDP19ttxI1QcQ4
    retry-0.9.3.1-5JV7A2DbgI48KaXjSrzETT
    scientific-0.3.8.1-DiNCmJn3LCGK1KM9YeO7Hp
    swagger2-2.8.10-2NqpOQqRFX45TWHtOldKqY text-2.0.2 time-1.12.2
    unix-2.8.4.0 unordered-containers-0.2.20.1-GdjPUvgItW77rL1YhzClz
    vault-0.3.1.6-Z2XWq6J1AyHRsjuCxBwNE
    vector-0.13.2.0-2P3Vv0GFH0i4NgSchvbpWK
    wai-3.2.4-7YbaDdPfmbRIZrux7wwPLM
    wai-cors-0.2.7-7K0AZZdwLBr44eqLWYU0Ew
    wai-extra-3.1.18-7lUf5TjX6RwFggje2DmIbv
    wai-logger-2.5.0-BgDOkEjehb27BQJrax94l7
    warp-3.4.0-CqhlxjL9IDTLCty6XoIIIa

haddock-interfaces:   /usr/share/doc/postgrest/html/postgrest.haddock
haddock-html:         /usr/share/doc/postgrest/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

